--
-- ExtendedCrawler
--
-- @author  Manuel Leithner
-- @date  21/09/17
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

ExtendedCrawler = {}

function ExtendedCrawler.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Crawler, specializations)
end

function ExtendedCrawler:load(savegame)


    local wheelId = Utils.getNoNil(self.configurations["wheel"], 1)
    local baseKey = string.format("vehicle.wheelConfigurations.wheelConfiguration(%d)", wheelId-1)
    if not hasXMLProperty(self.xmlFile, baseKey) then
        baseKey = "vehicle"
    end

    local i = 0
    while true do
        local key = string.format(baseKey..".crawlers.crawler(%d)", i)
        if not hasXMLProperty(self.xmlFile, key) then
            break
        end

        local crawler = self.crawlers[i+1]
        crawler.scrollParts = {}

        local j = 0
        while true do
            local keyScroll = key..string.format(".scrollPart(%d)", j)
            if not hasXMLProperty(self.xmlFile, keyScroll) then
                break
            end
            local scrollPart = {}
            scrollPart.node = Utils.indexToObject(crawler.baseNode, getXMLString(self.xmlFile, keyScroll.."#index"))
            scrollPart.scrollSpeed = Utils.getNoNil(getXMLFloat(self.xmlFile, keyScroll.."#scrollSpeed"), 1)
            scrollPart.scrollPosition = 0
            scrollPart.scrollLength = Utils.getNoNil(getXMLFloat(self.xmlFile, keyScroll.."#scrollLength"), 1)

            table.insert(crawler.scrollParts, scrollPart)
            j = j + 1
        end
        i = i + 1
    end

end

function ExtendedCrawler:delete()
end

function ExtendedCrawler:mouseEvent(posX, posY, isDown, isUp, button)
end

function ExtendedCrawler:keyEvent(unicode, sym, modifier, isDown)
end

function ExtendedCrawler:update(dt)
    if self:getIsActive() then
        for i, crawler in pairs(self.crawlers) do
            for _, scrollPart in pairs(crawler.scrollParts) do
                scrollPart.scrollPosition = (scrollPart.scrollPosition + crawler.movedDistance*scrollPart.scrollSpeed) % scrollPart.scrollLength
                setShaderParameter(scrollPart.node, "scrollPosition", scrollPart.scrollPosition,0,0,0, false)
            end
        end
    end
end

function ExtendedCrawler:draw()
end
